@@ -41,5 +41,6 @@ class ManifestValidationError(ManifestException):
     def __str__(self):
         return (
             "Invalid manifest fields: %s. \nPlease check specification -> "
-            "htts://docs.platformio.org/page/librarymanager/config.html" % self.messages
+            "https://docs.platformio.org/page/librarymanager/config.html"
+            % self.messages
         )
